# stat_prob_dist (Statistics and Probability Distributions) package

Summary of the package


# Files

Explanation of the files in the package


# Installation

Install information goes here 


# Usage:

Use demo

